@@ -2,7 +2,8 @@ import itk
 import numpy as np
 import os
 import opengate as gate
-import matplotlib.pyplot as plt
+import random
+import string
 import colored
 from box import Box, BoxList
 import scipy
@@ -12,7 +13,6 @@ import gatetools.phsp as phsp
 import pathlib
 import uproot
 import sys
-
 import matplotlib.pyplot as plt
 
 
@@ -35,15 +35,16 @@ def delete_run_manager_if_needed(sim):
     gate.warning(
         "WARNING, we need to delete G4RunManager, otherwise, GIL bug (seg fault)"
     )
-    if sim.g4_RunManager:
-        del sim.g4_RunManager
+    if "g4_RunManager" in sim.__dict__:
+        sim.g4_RunManager = None
     print("RunManager deleted.")
 
 
 def read_stat_file(filename):
     p = os.path.abspath(filename)
     f = open(p, "r")
-    a = gate.UserInfo("Actor", "SimulationStatisticsActor", filename)
+    r = "".join(random.choices(string.ascii_lowercase + string.digits, k=20))
+    a = gate.UserInfo("Actor", "SimulationStatisticsActor", r)
     stat = gate.SimulationStatisticsActor(a)
     # stat.counts = Box()
     read_track = False
@@ -224,7 +225,14 @@ def plot_img_x(ax, img, label):
 
 
 def assert_images(
-    ref_filename1, filename2, stats=None, tolerance=0, ignore_value=0, axis="z"
+    ref_filename1,
+    filename2,
+    stats=None,
+    tolerance=0,
+    ignore_value=0,
+    axis="z",
+    fig_name=None,
+    sum_tolerance=5,
 ):
     # read image and info (size, spacing etc)
     ref_filename1 = gate.check_filename_type(ref_filename1)
@@ -254,12 +262,18 @@ def assert_images(
     data1 = itk.GetArrayViewFromImage(img1).ravel()
     data2 = itk.GetArrayViewFromImage(img2).ravel()
 
-    print(
-        f"Image1: {info1.size} {info1.spacing} {info1.origin} sum={np.sum(data1):.2f} {ref_filename1}"
-    )
-    print(
-        f"Image2: {info2.size} {info2.spacing} {info2.origin} sum={np.sum(data2):.2f} {filename2}"
-    )
+    s1 = np.sum(data1)
+    s2 = np.sum(data2)
+    if s1 == 0 and s2 == 0:
+        t = 0
+    else:
+        t = np.fabs((s1 - s2) / s1) * 100
+    b = t < sum_tolerance
+    print_test(b, f"Img sums {s1} vs {s2} : {t:.2f} %  (tol {sum_tolerance:.2f} %)")
+    is_ok = is_ok and b
+
+    print(f"Image1: {info1.size} {info1.spacing} {info1.origin} {ref_filename1}")
+    print(f"Image2: {info2.size} {info2.spacing} {info2.origin} {filename2}")
 
     # do not consider pixels with a value of zero (data2 is the reference)
     d1 = data1[data2 != ignore_value]
@@ -289,7 +303,10 @@ def assert_images(
     fig, ax = plt.subplots(ncols=1, nrows=1, figsize=(25, 10))
     plot_img_axis(ax, img1, "reference", axis)
     plot_img_axis(ax, img2, "test", axis)
-    n = filename2.replace(".mhd", "_test.png")
+    if fig_name is None:
+        n = filename2.replace(".mhd", "_test.png")
+    else:
+        n = fig_name
     print("Save image test figure :", n)
     plt.savefig(n)
 
@@ -326,7 +343,7 @@ def get_new_key_name(key):
         ["energy", "TotalEnergyDeposit", 1, 0.001],
         ["Ekine", "KineticEnergy", 1, 0.001],
         ["time", "GlobalTime", 1e-9, 0.02],
-        ["posX", "PostPosition_X", 1, 0.9],
+        ["posX", "PostPosition_X", 1, 1],
         ["posY", "PostPosition_Y", 1, 0.9],
         ["posZ", "PostPosition_Z", 1, 0.7],
         ["globalPosX", "PostPosition_X", 1, 0.7],
@@ -433,8 +450,8 @@ def compare_branches(
     # get branches
     b1 = get_branch(tree1, keys1, key1) * scaling1
     b2 = get_branch(tree2, keys2, key2) * scaling2
-
-    return compare_branches_values(b1, b2, key1, key2, tol, ax, nb_bins)
+    is_ok = compare_branches_values(b1, b2, key1, key2, tol, ax, nb_bins)
+    return is_ok
 
 
 def compare_branches_values(b1, b2, key1, key2, tol=0.8, ax=False, nb_bins=200):
@@ -451,6 +468,9 @@ def compare_branches_values(b1, b2, key1, key2, tol=0.8, ax=False, nb_bins=200):
     m2 = np.mean(b2)
     n1 = np.size(b1)
     n2 = np.size(b2)
+    # sum
+    sum1 = np.sum(b1)
+    sum2 = np.sum(b2)
 
     # Earth mover distance (Wasserstein)
     wass = stats.wasserstein_distance(b1, b2)
@@ -459,7 +479,7 @@ def compare_branches_values(b1, b2, key1, key2, tol=0.8, ax=False, nb_bins=200):
     if not ok:
         oks = "fail"
     s = (
-        f"N: {n1:7} vs {n2:7} -> means {m1:6.2f} vs {m2:6.2f} -> ranges: {brange1:6.2f} vs {brange2:6.2f} "
+        f"N: {n1:7} vs {n2:7} -> means {m1:6.2f} vs {m2:6.2f} -> sums {sum1:6.2f} vs {sum2:6.2f}  -> ranges: {brange1:6.2f} vs {brange2:6.2f} "
         f" -> w:{wass:4.3f} vs {tol:4.3f}  \t {key1:<20} {key2:<20}  -> {oks} (tol {tol})"
     )
     print_test(ok, s)
@@ -505,22 +525,20 @@ def compare_trees(
             n += 1
         else:
             a = False
-        is_ok = (
-            compare_branches(
-                tree1,
-                allkeys1,
-                tree2,
-                allkeys2,
-                keys1[i],
-                keys2[i],
-                tols[i],
-                scalings1[i],
-                scalings2[i],
-                a,
-                nb_bins=nb_bins,
-            )
-            and is_ok
+        ia = compare_branches(
+            tree1,
+            allkeys1,
+            tree2,
+            allkeys2,
+            keys1[i],
+            keys2[i],
+            tols[i],
+            scalings1[i],
+            scalings2[i],
+            a,
+            nb_bins=nb_bins,
         )
+        is_ok = ia and is_ok
     if fig:
         phsp.fig_rm_empty_plot(nb_fig, n, ax)
     return is_ok
@@ -540,10 +558,14 @@ def get_default_test_paths(f, gate_folder=None):
 
 
 def compare_root2(root1, root2, branch1, branch2, keys, img_filename, n_tol=3):
+    if not os.path.isfile(root1):
+        gate.fatal(f"Cannot open root file '{root1}'")
     hits1 = uproot.open(root1)[branch1]
     hits1_n = hits1.num_entries
     hits1 = hits1.arrays(library="numpy")
 
+    if not os.path.isfile(root2):
+        gate.fatal(f"Cannot open root file '{root2}'")
     hits2 = uproot.open(root2)[branch2]
     hits2_n = hits2.num_entries
     hits2 = hits2.arrays(library="numpy")
@@ -723,7 +745,6 @@ def write_gauss_param_to_file(
     sigma_values = []
     mu_values = []
     for i in planePositionsV:
-
         filename = fNamePrefix + str(i) + fNameSuffix
         filepath = outputdir / filename
 
