@@ -2,10 +2,9 @@
 # -*- coding: utf-8 -*-
 
 import opengate as gate
-from test013_phys_lists_base import create_pl_sim, phys_em_parameters
-import pathlib
+from test013_phys_lists_helpers import create_pl_sim, phys_em_parameters
 
-pathFile = pathlib.Path(__file__).parent.resolve()
+paths = gate.get_default_test_paths(__file__, "gate_test013_phys_lists")
 
 # create simulation
 sim = create_pl_sim()
@@ -26,9 +25,6 @@ cuts.world.positron = 3 * mm
 cuts.waterbox.gamma = 2 * mm
 cuts.b2.electron = 5 * mm
 
-# initialize
-sim.initialize()
-
 # em parameters
 # phys_em_parameters(p)
 
@@ -38,21 +34,13 @@ print(sim.physics_manager.dump_cuts())
 # start simulation
 # sim.set_g4_verbose(True)
 # sim.apply_g4_command("/tracking/verbose 1")
-sim.start()
+output = sim.start()
 
-stats = sim.get_actor("Stats")
+stats = output.get_actor("Stats")
 
 # gate_test4_simulation_stats_actor
 # Gate mac/main_4.mac
-f = (
-    pathFile
-    / ".."
-    / "data"
-    / "gate"
-    / "gate_test013_phys_lists"
-    / "output"
-    / "stat_4.txt"
-)
+f = paths.gate_output / "stat_4.txt"
 print("Reference file", f)
 stats_ref = gate.read_stat_file(f)
 is_ok = gate.assert_stats(stats, stats_ref, tolerance=0.12)
