@@ -18,6 +18,7 @@ ui.g4_verbose = False
 ui.g4_verbose_level = 1
 ui.visu = False
 ui.check_volumes_overlap = True
+ui.random_seed = 123654987
 
 #  change world size
 m = gate.g4_units("m")
@@ -47,11 +48,10 @@ sec = gate.g4_units("second")
 sim.run_timing_intervals = [[0, 1 * sec]]
 
 # initialize & start
-sim.initialize()
-sim.start()
+output = sim.start()
 
 # print results at the end
-stats = sim.get_actor("stats")
+stats = output.get_actor("stats")
 print(stats)
 
 # check
