@@ -4,7 +4,7 @@
 import opengate as gate
 import opengate_core as g4
 from scipy.spatial.transform import Rotation
-import test036_adder_depth_base as t036
+import test036_adder_depth_helpers as t036
 import uproot
 import matplotlib.pyplot as plt
 
@@ -14,9 +14,9 @@ paths = gate.get_default_test_paths(__file__, "gate_test036_adder_depth")
 sim = t036.create_simulation("param")
 
 # start simulation
-sim.start()
+output = sim.start()
 
 # test the output
-is_ok = t036.test_output(sim)
+is_ok = t036.test_output(output)
 
 gate.test_ok(is_ok)
